@@ -1,23 +1,24 @@
+import os
+
 import pytest
 
 from hatch.project.core import Project
-from hatchling.utils.constants import DEFAULT_BUILD_SCRIPT
+from hatchling.utils.constants import DEFAULT_BUILD_SCRIPT, DEFAULT_CONFIG_FILE
+
+pytestmark = [pytest.mark.usefixtures("mock_backend_process")]
 
 
-@pytest.fixture(autouse=True)
-def local_builder(mock_backend_process, mocker):
-    mocker.patch('hatch.env.virtual.VirtualEnvironment.build_environment')
-    yield
+def test(hatch, temp_dir, helpers, config_file, mock_plugin_installation):
+    config_file.model.template.plugins["default"]["src-layout"] = False
+    config_file.save()
 
-
-def test(hatch, temp_dir, helpers):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
         assert result.exit_code == 0, result.output
 
-    path = temp_dir / 'my-app'
+    path = temp_dir / "my-app"
 
     build_script = path / DEFAULT_BUILD_SCRIPT
     build_script.write_text(
@@ -40,26 +41,36 @@ def test(hatch, temp_dir, helpers):
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['tool']['hatch']['build'] = {'hooks': {'custom': {'path': build_script.name}}}
+    config["tool"]["hatch"]["build"] = {"hooks": {"custom": {"path": build_script.name}}}
     project.save_config(config)
 
     with path.as_cwd():
-        result = hatch('build')
+        result = hatch("build")
         assert result.exit_code == 0, result.output
 
-    build_directory = path / 'dist'
+    build_directory = path / "dist"
     assert build_directory.is_dir()
-    build_artifact = path / 'my_app' / 'lib.so'
+    build_artifact = path / "my_app" / "lib.so"
     assert build_artifact.is_file()
 
     artifacts = list(build_directory.iterdir())
     assert len(artifacts) == 2
 
+    dependency = os.urandom(16).hex()
+    (path / DEFAULT_CONFIG_FILE).write_text(
+        helpers.dedent(
+            f"""
+            [env]
+            requires = ["{dependency}"]
+            """
+        )
+    )
+
     with path.as_cwd():
-        result = hatch('version', 'minor')
+        result = hatch("version", "minor")
         assert result.exit_code == 0, result.output
 
-        result = hatch('clean')
+        result = hatch("clean")
         assert result.exit_code == 0, result.output
 
     artifacts = list(build_directory.iterdir())
@@ -68,7 +79,8 @@ def test(hatch, temp_dir, helpers):
 
     assert result.output == helpers.dedent(
         """
-        Setting up build environment
-        Setting up build environment
+        Syncing environment plugin requirements
+        Inspecting build dependencies
         """
     )
+    helpers.assert_plugin_installation(mock_plugin_installation, [dependency], count=2)
