@@ -8,24 +8,24 @@ from .utils import update_record_file_contents
 
 
 def get_files(**kwargs):
-    metadata_directory = kwargs.get('metadata_directory', '')
-    shared_data_directory = kwargs.get('shared_data_directory', '')
+    metadata_directory = kwargs.get("metadata_directory", "")
+    shared_data_directory = kwargs.get("shared_data_directory", "")
 
     files = []
     for f in get_template_files(**kwargs):
-        if str(f.path) == 'LICENSE.txt':
-            files.append(File(Path(metadata_directory, 'licenses', f.path), f.contents))
+        if str(f.path) == "LICENSE.txt":
+            files.append(File(Path(metadata_directory, "licenses", f.path), f.contents))
 
-        if f.path.parts[0] != kwargs['package_name']:
+        if f.path.parts[0] != kwargs["package_name"]:
             continue
 
         files.append(f)
 
     files.extend((
-        File(Path(shared_data_directory, 'data', 'foo.txt'), ''),
-        File(Path(shared_data_directory, 'data', 'nested', 'bar.txt'), ''),
+        File(Path(shared_data_directory, "data", "foo.txt"), ""),
+        File(Path(shared_data_directory, "data", "nested", "bar.txt"), ""),
         File(
-            Path(metadata_directory, 'WHEEL'),
+            Path(metadata_directory, "WHEEL"),
             f"""\
 Wheel-Version: 1.0
 Generator: hatchling {__version__}
@@ -34,10 +34,10 @@ Tag: py3-none-any
 """,
         ),
         File(
-            Path(metadata_directory, 'METADATA'),
+            Path(metadata_directory, "METADATA"),
             f"""\
 Metadata-Version: {DEFAULT_METADATA_VERSION}
-Name: {kwargs['project_name']}
+Name: {kwargs["project_name"]}
 Version: 0.0.1
 License-File: LICENSE.txt
 Requires-Python: >3
@@ -45,7 +45,7 @@ Requires-Python: >3
         ),
     ))
 
-    record_file = File(Path(metadata_directory, 'RECORD'), '')
+    record_file = File(Path(metadata_directory, "RECORD"), "")
     update_record_file_contents(record_file, files)
     files.append(record_file)
 
